==> gitlab-18.6.2-1-x86_64.pkg.tar.zst: usr/share/webapps/gitlab/doc-locale/ja-jp/tutorials/gitlab_navigation.md <==
---
stage: none
group: Tutorials
info: For assistance with this tutorials page, see https://handbook.gitlab.com/handbook/product/ux/technical-writing/#assignments-to-other-projects-and-subjects.
description: 製品の紹介。
title: 'チュートリアル: GitLabの操作方法を理解する'
---

GitLabの機能とその機能がある場所を知ることで、すぐに使いこなせるようになります。

| トピック | 説明 | 初心者向け |
|-------|-------------|--------------------|
| [GitLab with Git Essentials（GitLabとGitの基本）](https://university.gitlab.com/courses/gitlab-with-git-essentials-s2)  |  この自主学習コースでGitとGitLabの基本を学びましょう。 | {{< icon name="star" >}} |
| <i class="fa fa-youtube-play youtube" aria-hidden="true"></i>[30日間のトライアルを開始する方法](https://www.youtube.com/watch?v=dIlBLrXbfrM&list=PLFGfElNsQthYDx0A_FaNNfUm9NHsK6zED&index=63) （3分01秒） | 30日間のUltimateプラントライアルを開始して、最初のプロジェクトを作成する方法を説明します。 | {{< icon name="star" >}} |
| [左側のサイドバーを使用してGitLab内を移動する](left_sidebar/_index.md) |  GitLabのUIを操作してみましょう。 | {{< icon name="star" >}} |
| [パーソナルホームページを使用する](personal_homepage/_index.md) |  GitLab全体でのアクティビティーを追跡するために、個人用ホームページを使用する方法を説明します。 | |
| <i class="fa fa-youtube-play youtube" aria-hidden="true"></i> [GitLab Continuous Delivery overview](https://www.youtube.com/watch?v=M7rBDZYsx8U&list=PLFGfElNsQthYDx0A_FaNNfUm9NHsK6zED&index=193)（GitLabの継続的デリバリーの概要）（17分2秒） | GitLabの機能を使用して、反復的なコードの変更を継続的にビルド、テスト、デプロイする方法を学びましょう。 | |

## チュートリアルのコンテンツをもっと探す {#find-more-tutorial-content}

- [GitLab University](https://university.gitlab.com/)で、学習トラックと認定オプションをご覧ください。
- [GitLab](https://about.gitlab.com/blog/)ブログで、最近のチュートリアルをご覧ください。
- ビデオチュートリアルを見つけるには、**GitLab Snapshots** [YouTubeのプレイリスト](https://www.youtube.com/playlist?list=PLFGfElNsQthYDx0A_FaNNfUm9NHsK6zED)をご覧ください。

==> gitlab-18.9.1-1-x86_64.pkg.tar.zst: usr/share/webapps/gitlab/doc-locale/ja-jp/tutorials/gitlab_navigation.md <==
---
stage: none
group: Tutorials
info: For assistance with this tutorials page, see https://handbook.gitlab.com/handbook/product/ux/technical-writing/#assignments-to-other-projects-and-subjects.
description: 製品の紹介。
title: 'チュートリアル: GitLabの操作方法を理解する'
---

GitLabの機能とその機能がある場所を知ることで、すぐに使いこなせるようになります。

| トピック | 説明 | 初心者向け |
|-------|-------------|--------------------|
| [GitLab with Git Essentials（GitLabとGitの基本）](https://university.gitlab.com/courses/gitlab-with-git-essentials-s2-jp)  |  この自主学習コースでGitとGitLabの基本を学びましょう。 | {{< icon name="star" >}} |
| <i class="fa fa-youtube-play youtube" aria-hidden="true"></i>[30日間のトライアルを開始する方法](https://www.youtube.com/watch?v=dIlBLrXbfrM&list=PLFGfElNsQthYDx0A_FaNNfUm9NHsK6zED&index=63) （3分01秒） | 30日間のUltimateプラントライアルを開始して、最初のプロジェクトを作成する方法を説明します。 | {{< icon name="star" >}} |
| [左側のサイドバーを使用してGitLab内を移動する](left_sidebar/_index.md) |  GitLabのUIを操作してみましょう。 | {{< icon name="star" >}} |
| [パーソナルホームページを使用する](personal_homepage/_index.md) |  GitLab全体でのアクティビティーを追跡するために、個人用ホームページを使用する方法を説明します。 | |
| <i class="fa fa-youtube-play youtube" aria-hidden="true"></i> [GitLab Continuous Delivery overview](https://www.youtube.com/watch?v=M7rBDZYsx8U&list=PLFGfElNsQthYDx0A_FaNNfUm9NHsK6zED&index=193)（GitLabの継続的デリバリーの概要）（17分2秒） | GitLabの機能を使用して、反復的なコードの変更を継続的にビルド、テスト、デプロイする方法を学びましょう。 | |

## チュートリアルのコンテンツをもっと探す {#find-more-tutorial-content}

- [GitLab University](https://university.gitlab.com/)で、学習トラックと認定オプションをご覧ください。
- [GitLab](https://about.gitlab.com/blog/)ブログで、最近のチュートリアルをご覧ください。
- ビデオチュートリアルを見つけるには、**GitLab Snapshots** [YouTubeのプレイリスト](https://www.youtube.com/playlist?list=PLFGfElNsQthYDx0A_FaNNfUm9NHsK6zED)をご覧ください。
